pub struct BeaconObjectiveDone {
id: usize,
name: String,
start: DateTime<Utc>,
end: DateTime<Utc>,
guesses: Vec<Vec2D<I32F32>>,
submitted: bool,
}Expand description
Represents a completed beacon objective.
Stores relevant details such as the objective’s ID, name, start and end time, and additional metadata like guesses and submission status.
Fields
id: usizeThe unique identifier of the objective.
name: StringThe name of the objective.
start: DateTime<Utc>The start time of the objective.
end: DateTime<Utc>The end time of the objective.
guesses: Vec<Vec2D<I32F32>>A collection of guesses made for the beacon position.
submitted: boolStatus indicating whether the guesses have been submitted.
Implementations
Sourceimpl BeaconObjectiveDone
impl BeaconObjectiveDone
Sourceconst MAP_WIDTH_RANGE: Range<u32>
const MAP_WIDTH_RANGE: Range<u32>
The allowed range for map width values.
Sourceconst MAP_HEIGHT_RANGE: Range<u32>
const MAP_HEIGHT_RANGE: Range<u32>
The allowed range for map height values.
Sourceconst MIN_DISTANCE_RAND_GUESSES: f32 = 75f32
const MIN_DISTANCE_RAND_GUESSES: f32 = 75f32
The minimum allowable distance between random guesses.
Sourcepub fn guesses(&self) -> &Vec<Vec2D<I32F32>>
pub fn guesses(&self) -> &Vec<Vec2D<I32F32>>
Returns a reference to the guesses for the beacon objective.
Sourcepub fn set_submitted(&mut self)
pub fn set_submitted(&mut self)
Sets the submission status of the guesses to true.
Sourcepub async fn guess_max(&self, client: Arc<HTTPClient>)
pub async fn guess_max(&self, client: Arc<HTTPClient>)
Sourcepub async fn randomize_no_meas_guesses(&self, client: Arc<HTTPClient>)
pub async fn randomize_no_meas_guesses(&self, client: Arc<HTTPClient>)
Randomizes guesses for the beacon if none are provided and submits them.
Arguments
client- HTTP client used to send requests.
Sourceasync fn submit_guess(
&self,
req: BeaconPositionRequest,
client: Arc<HTTPClient>,
guess: &Vec2D<I32F32>,
guess_num: usize,
) -> Result<Option<()>, Error>
async fn submit_guess( &self, req: BeaconPositionRequest, client: Arc<HTTPClient>, guess: &Vec2D<I32F32>, guess_num: usize, ) -> Result<Option<()>, Error>
Submits a single guess to the server.
Arguments
req- The request containing the guess information.client- HTTP client used to send the request.guess- The guessed position.guess_num- The number of the guess to provide contextual information.
Returns
Ok(Some(()))if the guess is successful.Ok(None)if the guess fails but the process is not over.Errif an error occurs or all attempts are exhausted.